@@ -3,7 +3,29 @@ package OpenTracing::Implementation;
 use strict;
 use warnings;
 
-our $VERSION = 'v0.32.0';
+our $VERSION = 'v0.33.0';
+
+sub OT_IMPLEMENTATION_NAME {
+    exists $ENV{ PERL_OPENTRACING_IMPLEMENTATION } ?
+        $ENV{ PERL_OPENTRACING_IMPLEMENTATION } :
+    exists $ENV{ OPENTRACING_IMPLEMENTATION } ?
+        $ENV{ OPENTRACING_IMPLEMENTATION } :
+    'NoOp'
+}
+
+sub OT_DEBUG {
+    exists $ENV{ PERL_OPENTRACING_DEBUG } ?
+        $ENV{ PERL_OPENTRACING_DEBUG } :
+    exists $ENV{ OPENTRACING_DEBUG } ?
+        $ENV{ OPENTRACING_DEBUG } :
+    exists $ENV{ DEBUG } ?
+        $ENV{ DEBUG } :
+    undef
+}
+#
+# it was meant to be a constant, but during test, these seem to be dynamic
+
+
 
 use OpenTracing::GlobalTracer;
 
@@ -24,11 +46,12 @@ sub bootstrap_tracer         { shift->_build_tracer( @_ ) }
 sub bootstrap_default_tracer { shift->_build_tracer( undef, @_ ) }
 
 sub bootstrap_global_tracer {
-    my $package = shift;
-    my $tracer = $package->_build_tracer( @_ );
-    
-    OpenTracing::GlobalTracer->set_global_tracer( $tracer );
-    
+    OpenTracing::GlobalTracer->set_global_tracer( shift->_build_tracer( @_ ) );
+    return OpenTracing::GlobalTracer->get_global_tracer
+}
+
+sub bootstrap_global_default_tracer {
+    OpenTracing::GlobalTracer->set_global_tracer( shift->_build_tracer( undef, @_ ) );
     return OpenTracing::GlobalTracer->get_global_tracer
 }
 
@@ -45,7 +68,7 @@ sub _build_tracer {
         __PACKAGE__->_get_implementation_class( $implementation_name );
     
     carp "Loading implementation $implementation_class"
-        if $ENV{OPENTRACING_DEBUG};
+        if OT_DEBUG;
     
     load $implementation_class;
     
@@ -60,11 +83,8 @@ sub _build_tracer {
 
 sub _get_implementation_class {
     my $class = shift;
-    my $implementation_name = shift;
+    my $implementation_name = shift // OT_IMPLEMENTATION_NAME;
     
-    $implementation_name = $ENV{OPENTRACING_IMPLEMENTATION} || 'NoOp'
-        unless defined $implementation_name;
-
     my $implementation_class = substr( $implementation_name, 0, 1) eq '+' ?
         substr( $implementation_name, 1 )
         :
